@@ -1,15 +1,17 @@
 #' Outputting HTML tables in RStudio viewer/R Notebooks
 #' 
-#' This is method for rendering results of \link{fre}/\link{cro}/\link{tables} 
-#' in Shiny/RMarkdown/Jupyter notebooks and etc. For detailed description of 
-#' function and its arguments see \link[htmlTable]{htmlTable}. You may be 
-#' interested in \code{expss_output_viewer()} for automatical rendering tables 
-#' in the RStudio viewer or  \code{expss_output_rnotebook()} for rendering in 
-#' the R notebooks. See \link{expss.options}. \code{repr_html} is method for 
-#' rendering table in the Jupyter notebooks and \code{knit_print} is method for 
-#' rendering table in the \code{knitr} HTML-documents. Jupyter notebooks and 
-#' \code{knitr} documents are supported automatically but in the R notebooks it 
-#' is needed to set output to notebook via \code{expss_output_rnotebook()}.
+#' This is method for rendering results of \link{fre}/\link{cro}/\link{tables}
+#' in Shiny/RMarkdown/Jupyter notebooks and etc. For detailed description of
+#' function and its arguments see \link[htmlTable]{htmlTable}. You can pack your
+#' tables in the list and render them all simultaneously. See examples. You may
+#' be interested in \code{expss_output_viewer()} for automatical rendering
+#' tables in the RStudio viewer or  \code{expss_output_rnotebook()} for
+#' rendering in the R notebooks. See \link{expss.options}. \code{repr_html} is
+#' method for rendering table in the Jupyter notebooks and \code{knit_print} is
+#' method for rendering table in the \code{knitr} HTML-documents. Jupyter
+#' notebooks and \code{knitr} documents are supported automatically but in the R
+#' notebooks it is needed to set output to notebook via
+#' \code{expss_output_rnotebook()}.
 #'
 #' @param x a data object of class 'etable' - result of \link{fre}/\link{cro} and etc.
 #' @param obj a data object of class 'etable' - result of \link{fre}/\link{cro} and etc.
@@ -20,6 +22,8 @@
 #' @param escape.html logical: should HTML characters be escaped? Defaults to FALSE. 
 #' @param ... further parameters for \link[htmlTable]{htmlTable}.
 #' @param row_groups logical Should we create row groups? TRUE by default.
+#' @param gap character Separator between tables if we output list of
+#'   tables. By default it is line break '<br>'.
 #'
 #' @return Returns a string of class htmlTable
 #' @export
@@ -52,14 +56,23 @@
 #'      tab_stat_mean() %>% 
 #'      tab_cells(cyl) %>% 
 #'      tab_stat_cpct() %>% 
-#'      tab_pivot()
+#'      tab_pivot() %>% 
+#'      set_caption("Table 1. Some variables from mtcars dataset.")
+#'      
+#' # several tables in a list
+#' mtcars %>% 
+#'     calc(list(
+#'         cro_cpct(list(am, vs, cyl), list(total(), am)) %>% set_caption("Table 1. Percent."),   
+#'         cro_mean_sd_n(list(mpg, hp, qsec), list(total(), am)) %>% set_caption("Table 2. Means.")
+#'     )) %>% 
+#'     htmlTable()
 #'      
 #' expss_output_default()   
 #'  
 #' }
 htmlTable.etable = function(x, digits = get_expss_digits(), escape.html = FALSE, ..., row_groups = TRUE){
     if(NCOL(x) == 0){
-        return(htmlTable(setNames(dtfrm("Table is empty"), " "), escape.html = escape.html, ...))
+        return(htmlTable(setNames(sheet("Table is empty"), " "), escape.html = escape.html, ...))
     }
     # because rowlabels and column names never escaped
     dollar = "&#36;"
@@ -161,7 +174,7 @@ htmlTable.etable = function(x, digits = get_expss_digits(), escape.html = FALSE,
         n.rgroup = NULL
     } else {
         if(NCOL(row_labels) > 2){
-            x = dtfrm(row_labels[, -(1:2)], x)
+            x = sheet(row_labels[, -(1:2)], x)
             html_header = c(rep("", NCOL(row_labels) - 2), html_header)
             align = c(rep("l", NCOL(row_labels) - 2), align)
             if(NROW(cgroup)>0){
@@ -190,7 +203,7 @@ htmlTable.etable = function(x, digits = get_expss_digits(), escape.html = FALSE,
         cgroup = cgroup[,colSums(!is.na(cgroup))>0, drop = FALSE]
         n.cgroup = n.cgroup[,colSums(!is.na(n.cgroup))>0, drop = FALSE]
         if(is.null(rgroup)){
-            htmlTable(as.dtfrm(x), 
+            htmlTable(as.sheet(x), 
                       header = html_header,
                       cgroup = cgroup, 
                       align = align,
@@ -200,7 +213,7 @@ htmlTable.etable = function(x, digits = get_expss_digits(), escape.html = FALSE,
                       escape.html = escape.html, 
                       ...)   
         } else {
-            htmlTable(as.dtfrm(x), 
+            htmlTable(as.sheet(x), 
                       header = html_header,
                       cgroup = cgroup, 
                       align = align,
@@ -214,7 +227,7 @@ htmlTable.etable = function(x, digits = get_expss_digits(), escape.html = FALSE,
         }
     } else {
         if(is.null(rgroup)){
-            htmlTable(as.dtfrm(x), 
+            htmlTable(as.sheet(x), 
                       header = html_header,
                       align = align,
                       rnames = rnames, 
@@ -222,7 +235,7 @@ htmlTable.etable = function(x, digits = get_expss_digits(), escape.html = FALSE,
                       escape.html = escape.html, 
                       ...)   
         } else {
-            htmlTable(as.dtfrm(x), 
+            htmlTable(as.sheet(x), 
                       header = html_header,
                       align = align,
                       rnames = rnames, 
@@ -235,7 +248,7 @@ htmlTable.etable = function(x, digits = get_expss_digits(), escape.html = FALSE,
     }
     } else {
         x = rep("", NROW(x))
-        htmlTable(dtfrm(x), 
+        htmlTable(sheet(x), 
                   header = "",
                   rnames = rnames, 
                   rgroup = rgroup,
@@ -248,6 +261,25 @@ htmlTable.etable = function(x, digits = get_expss_digits(), escape.html = FALSE,
  
 }
 
+#' @export
+#' @rdname htmlTable.etable
+htmlTable.with_caption = function(x, digits = get_expss_digits(), escape.html = FALSE, ..., row_groups = TRUE){
+    caption = get_caption(x)
+    x = set_caption(x, NULL)
+    htmlTable(x, caption = caption, digits = digits, escape.html = escape.html, ..., row_groups = row_groups)
+}
+
+
+#' @export
+#' @rdname htmlTable.etable
+htmlTable.list = function(x, gap = "<br>", ...){
+    res = lapply(x, htmlTable, ...)
+    res = do.call(paste, c(res, list(sep = gap)))
+    class(res) = c("htmlTable", "character")
+    res
+}
+
+
 matrix_to_cgroup = function(header){
     
     rle_list = list()
@@ -283,7 +315,15 @@ knit_print.etable = function(x, digits = get_expss_digits(), escape.html = FALSE
     knitr::knit_print(htmlTable.etable(x, digits = digits, 
                                        escape.html = escape.html,
                                        ..., row_groups = TRUE))
-    # knitr::asis_output(res)
+}
+
+#' @export
+#' @rdname htmlTable.etable
+knit_print.with_caption = function(x, digits = get_expss_digits(), escape.html = FALSE, ...){
+    knitr::knit_print(htmlTable.with_caption(x, digits = digits, 
+                                             escape.html = escape.html,
+                                             ..., row_groups = TRUE)
+    )
 }
 
 
@@ -294,6 +334,12 @@ repr_html.etable = function(obj, digits = get_expss_digits(), escape.html = FALS
     
 }
 
+#' @export
+#' @rdname htmlTable.etable
+repr_html.with_caption = function(obj, digits = get_expss_digits(), escape.html = FALSE, ...){
+    htmlTable(obj, digits = digits, escape.html = escape.html, ..., row_groups = FALSE)
+}
+
 #' @export
 #' @rdname htmlTable.etable
 repr_text.etable = function(obj, digits = get_expss_digits(), ...){
@@ -318,6 +364,15 @@ repr_text.etable = function(obj, digits = get_expss_digits(), ...){
     
 }
 
+repr_text.with_caption = function(obj, digits = get_expss_digits(), ...){
+    width = getOption("width")
+    on.exit(options(width = width))
+    options(width = 1000)
+    paste(capture.output(print(obj, digits = digits, ...)),
+          collapse = "\n")
+    
+}
+
 ## for Jupyter notebooks where row headings are not rendered correctly
 html_table_no_row_groups = function(x, escape.html = FALSE, ...){
     if(!escape.html){
@@ -376,7 +431,7 @@ html_table_no_row_groups = function(x, escape.html = FALSE, ...){
         rnames = row_labels[,1] 
     } else {
         if(NCOL(row_labels) > 1){
-            x = dtfrm(row_labels[, -1], x)
+            x = sheet(row_labels[, -1], x)
             html_header = c(rep("", NCOL(row_labels) - 1), html_header)
             align = c(rep("l", NCOL(row_labels) - 1), align)
             if(NROW(cgroup)>0){
@@ -397,7 +452,7 @@ html_table_no_row_groups = function(x, escape.html = FALSE, ...){
         if(NROW(cgroup)>0){
             cgroup = cgroup[,colSums(!is.na(cgroup))>0, drop = FALSE]
             n.cgroup = n.cgroup[,colSums(!is.na(n.cgroup))>0, drop = FALSE]
-                htmlTable(as.dtfrm(x), 
+                htmlTable(as.sheet(x), 
                           header = html_header,
                           cgroup = cgroup, 
                           align = align,
@@ -409,7 +464,7 @@ html_table_no_row_groups = function(x, escape.html = FALSE, ...){
             
         } else {
 
-                htmlTable(as.dtfrm(x), 
+                htmlTable(as.sheet(x), 
                           header = html_header,
                           align = align,
                           rnames = rnames, 
@@ -420,7 +475,7 @@ html_table_no_row_groups = function(x, escape.html = FALSE, ...){
         }
     } else {
         x = rep("", NROW(x))
-        htmlTable(dtfrm(x), 
+        htmlTable(sheet(x), 
                   header = "",
                   rnames = rnames, 
                   rowlabel = first_lab,
@@ -430,3 +485,4 @@ html_table_no_row_groups = function(x, escape.html = FALSE, ...){
     }
     
 }
+
