@@ -226,6 +226,10 @@ in_place_if_val = function(x, ..., from = NULL, to = NULL){
 #' @rdname experimental
 .cro = eval_in_default_dataset
 
+#' @export
+#' @rdname experimental
+.cro_cases = eval_in_default_dataset
+
 #' @export
 #' @rdname experimental
 .cro_cpct = eval_in_default_dataset
@@ -250,6 +254,10 @@ in_place_if_val = function(x, ..., from = NULL, to = NULL){
 #' @rdname experimental
 .cro_median = eval_in_default_dataset
 
+#' @export
+#' @rdname experimental
+.cro_mean_sd_n = eval_in_default_dataset
+
 #' @export
 #' @rdname experimental
 .cro_fun = eval_in_default_dataset
